@@ -1,5 +1,4 @@
 from .database import (  # noqa
-    analyze,
     create_database,
     database_exists,
     drop_database,
@@ -7,18 +6,20 @@ from .database import (  # noqa
     has_index,
     has_unique_index,
     is_auto_assigned_date_column,
-    json_sql
+    json_sql,
+    jsonb_sql
 )
 from .foreign_keys import (  # noqa
     dependent_objects,
+    get_fk_constraint_for_columns,
     get_referencing_foreign_keys,
     group_foreign_keys,
-    is_indexed_foreign_key,
     merge_references,
     non_indexed_foreign_keys
 )
 from .mock import create_mock_engine, mock_engine  # noqa
 from .orm import (  # noqa
+    cast_if,
     get_bind,
     get_class_by_table,
     get_column_key,
