@@ -27,7 +27,7 @@ class TestDatabaseSQLiteMemory(object):
         assert database_exists(dsn)
 
 
-@pytest.mark.usefixture('sqlite_none_database_dsn')
+@pytest.mark.usefixtures('sqlite_none_database_dsn')
 class TestDatabaseSQLiteMemoryNoDatabaseString(object):
     def test_exists_memory_none_database(self, sqlite_none_database_dsn):
         assert database_exists(sqlite_none_database_dsn)
@@ -35,7 +35,10 @@ class TestDatabaseSQLiteMemoryNoDatabaseString(object):
 
 @pytest.mark.usefixtures('sqlite_file_dsn')
 class TestDatabaseSQLiteFile(DatabaseTest):
-    pass
+    def test_existing_non_sqlite_file(self, dsn):
+        database = sa.engine.url.make_url(dsn).database
+        open(database, 'w').close()
+        self.test_create_and_drop(dsn)
 
 
 @pytest.mark.skipif('pymysql is None')
@@ -72,12 +75,32 @@ class TestDatabasePostgres(DatabaseTest):
                 "TEMPLATE my_template"
             )
         )
-        dsn = 'postgres://{0}@localhost/db_test_sqlalchemy_util'.format(
+        dsn = 'postgresql://{0}@localhost/db_test_sqlalchemy_util'.format(
             postgresql_db_user
         )
         create_database(dsn, template='my_template')
 
 
+class TestDatabasePostgresPg8000(DatabaseTest):
+
+    @pytest.fixture
+    def dsn(self, postgresql_db_user):
+        return 'postgresql+pg8000://{0}@localhost/{1}'.format(
+            postgresql_db_user,
+            'db_to_test_create_and_drop_via_pg8000_driver'
+        )
+
+
+class TestDatabasePostgresPsycoPG2CFFI(DatabaseTest):
+
+    @pytest.fixture
+    def dsn(self, postgresql_db_user):
+        return 'postgresql+psycopg2cffi://{0}@localhost/{1}'.format(
+            postgresql_db_user,
+            'db_to_test_create_and_drop_via_psycopg2cffi_driver'
+        )
+
+
 @pytest.mark.usefixtures('postgresql_dsn')
 class TestDatabasePostgresWithQuotedName(DatabaseTest):
 
@@ -95,7 +118,7 @@ class TestDatabasePostgresWithQuotedName(DatabaseTest):
                 'TEMPLATE "my-template"'
             )
         )
-        dsn = 'postgres://{0}@localhost/db_test_sqlalchemy-util'.format(
+        dsn = 'postgresql://{0}@localhost/db_test_sqlalchemy-util'.format(
             postgresql_db_user
         )
         create_database(dsn, template='my-template')
@@ -104,7 +127,7 @@ class TestDatabasePostgresWithQuotedName(DatabaseTest):
 class TestDatabasePostgresCreateDatabaseCloseConnection(object):
     def test_create_database_twice(self, postgresql_db_user):
         dsn_list = [
-            'postgres://{0}@localhost/db_test_sqlalchemy-util-a'.format(
+            'postgresql://{0}@localhost/db_test_sqlalchemy-util-a'.format(
                 postgresql_db_user
             ),
             'postgres://{0}@localhost/db_test_sqlalchemy-util-b'.format(
@@ -118,3 +141,12 @@ class TestDatabasePostgresCreateDatabaseCloseConnection(object):
         for dsn_item in dsn_list:
             drop_database(dsn_item)
             assert not database_exists(dsn_item)
+
+
+@pytest.mark.usefixtures('mssql_dsn')
+class TestDatabaseMssql(DatabaseTest):
+
+    @pytest.fixture
+    def db_name(self):
+        pytest.importorskip('pyodbc')
+        return 'db_test_sqlalchemy_util'
