@@ -4,10 +4,13 @@ import pytest
 import sqlalchemy as sa
 
 from sqlalchemy_utils import ColorType, EncryptedType, PhoneNumberType
-from sqlalchemy_utils.types.encrypted import (
+from sqlalchemy_utils.types import JSONType
+from sqlalchemy_utils.types.encrypted.encrypted_type import (
     AesEngine,
+    AesGcmEngine,
     DatetimeHandler,
-    FernetEngine
+    FernetEngine,
+    InvalidCiphertextError
 )
 
 cryptography = None
@@ -18,7 +21,7 @@ except ImportError:
 
 
 @pytest.fixture
-def User(Base, encryption_engine, test_key):
+def User(Base, encryption_engine, test_key, padding_mechanism):
     class User(Base):
         __tablename__ = 'user'
         id = sa.Column(sa.Integer, primary_key=True)
@@ -26,61 +29,78 @@ def User(Base, encryption_engine, test_key):
         username = sa.Column(EncryptedType(
             sa.Unicode,
             test_key,
-            encryption_engine)
+            encryption_engine,
+            padding_mechanism)
         )
 
         access_token = sa.Column(EncryptedType(
             sa.String,
             test_key,
-            encryption_engine)
+            encryption_engine,
+            padding_mechanism)
         )
 
         is_active = sa.Column(EncryptedType(
             sa.Boolean,
             test_key,
-            encryption_engine)
+            encryption_engine,
+            padding_mechanism)
         )
 
         accounts_num = sa.Column(EncryptedType(
             sa.Integer,
             test_key,
-            encryption_engine)
+            encryption_engine,
+            padding_mechanism)
         )
 
         phone = sa.Column(EncryptedType(
             PhoneNumberType,
             test_key,
-            encryption_engine)
+            encryption_engine,
+            padding_mechanism)
         )
 
         color = sa.Column(EncryptedType(
             ColorType,
             test_key,
-            encryption_engine)
+            encryption_engine,
+            padding_mechanism)
         )
 
         date = sa.Column(EncryptedType(
             sa.Date,
             test_key,
-            encryption_engine)
+            encryption_engine,
+            padding_mechanism)
         )
 
         time = sa.Column(EncryptedType(
             sa.Time,
             test_key,
-            encryption_engine)
+            encryption_engine,
+            padding_mechanism)
         )
 
         datetime = sa.Column(EncryptedType(
             sa.DateTime,
             test_key,
-            encryption_engine)
+            encryption_engine,
+            padding_mechanism)
         )
 
         enum = sa.Column(EncryptedType(
             sa.Enum('One', name='user_enum_t'),
             test_key,
-            encryption_engine)
+            encryption_engine,
+            padding_mechanism)
+        )
+
+        json = sa.Column(EncryptedType(
+            JSONType,
+            test_key,
+            encryption_engine,
+            padding_mechanism)
         )
 
     return User
@@ -111,6 +131,11 @@ def user_enum():
     return 'One'
 
 
+@pytest.fixture
+def user_json():
+    return {"key": "value"}
+
+
 @pytest.fixture
 def user_date():
     return date(2010, 10, 2)
@@ -158,6 +183,7 @@ def user(
     user_date,
     user_time,
     user_enum,
+    user_json,
     user_datetime,
     test_token,
     active,
@@ -171,6 +197,7 @@ def user(
     user.date = user_date
     user.time = user_time
     user.enum = user_enum
+    user.json = user_json
     user.datetime = user_datetime
     user.access_token = test_token
     user.is_active = active
@@ -217,7 +244,7 @@ def date_simple():
 class EncryptedTypeTestCase(object):
 
     @pytest.fixture
-    def Team(self, Base, encryption_engine):
+    def Team(self, Base, encryption_engine, padding_mechanism):
         self._team_key = None
 
         class Team(Base):
@@ -227,7 +254,8 @@ class EncryptedTypeTestCase(object):
             name = sa.Column(EncryptedType(
                 sa.Unicode,
                 lambda: self._team_key,
-                encryption_engine)
+                encryption_engine,
+                padding_mechanism)
             )
         return Team
 
@@ -265,6 +293,9 @@ class EncryptedTypeTestCase(object):
     def test_enum(self, user, user_enum):
         assert user.enum == user_enum
 
+    def test_json(self, user, user_json):
+        assert user.json == user_json
+
     def test_lookup_key(self, session, Team):
         # Add teams
         self._team_key = 'one'
@@ -289,9 +320,6 @@ class EncryptedTypeTestCase(object):
 
         assert team.name == u'One'
 
-        with pytest.raises(Exception):
-            session.query(Team).get(team_2_id)
-
         session.expunge_all()
 
         self._team_key = session.query(Team.key).filter_by(
@@ -302,9 +330,6 @@ class EncryptedTypeTestCase(object):
 
         assert team.name == u'Two'
 
-        with pytest.raises(Exception):
-            session.query(Team).get(team_1_id)
-
         session.expunge_all()
 
         # Remove teams
@@ -312,7 +337,7 @@ class EncryptedTypeTestCase(object):
         session.commit()
 
 
-class TestAesEncryptedTypeTestcase(EncryptedTypeTestCase):
+class AesEncryptedTypeTestCase(EncryptedTypeTestCase):
 
     @pytest.fixture
     def encryption_engine(self):
@@ -325,6 +350,34 @@ class TestAesEncryptedTypeTestcase(EncryptedTypeTestCase):
 
         assert test.username == user.username
 
+
+class TestAesEncryptedTypeWithPKCS5Padding(AesEncryptedTypeTestCase):
+
+    @pytest.fixture
+    def padding_mechanism(self):
+        return 'pkcs5'
+
+
+class TestAesEncryptedTypeWithOneAndZeroesPadding(AesEncryptedTypeTestCase):
+
+    @pytest.fixture
+    def padding_mechanism(self):
+        return 'oneandzeroes'
+
+
+class TestAesEncryptedTypeWithZeroesPadding(AesEncryptedTypeTestCase):
+
+    @pytest.fixture
+    def padding_mechanism(self):
+        return 'zeroes'
+
+
+class TestAesEncryptedTypeTestcaseWithNaivePadding(AesEncryptedTypeTestCase):
+
+    @pytest.fixture
+    def padding_mechanism(self):
+        return 'naive'
+
     def test_decrypt_raises_value_error_with_invalid_key(self, session, Team):
         self._team_key = 'one'
         team = Team(key=self._team_key, name=u'One')
@@ -342,11 +395,17 @@ class TestFernetEncryptedTypeTestCase(EncryptedTypeTestCase):
     def encryption_engine(self):
         return FernetEngine
 
+    @pytest.fixture
+    def padding_mechanism(self):
+        return None
+
 
 class TestDatetimeHandler(object):
 
-    def test_datetime_with_micro_and_timezone(self):
-        original_datetime = datetime_with_micro_and_timezone()
+    def test_datetime_with_micro_and_timezone(
+        self, datetime_with_micro_and_timezone
+    ):
+        original_datetime = datetime_with_micro_and_timezone
         original_datetime_isoformat = original_datetime.isoformat()
         python_type = datetime
 
@@ -355,8 +414,8 @@ class TestDatetimeHandler(object):
             python_type
         ) == original_datetime
 
-    def test_datetime_with_micro(self):
-        original_datetime = datetime_with_micro()
+    def test_datetime_with_micro(self, datetime_with_micro):
+        original_datetime = datetime_with_micro
         original_datetime_isoformat = original_datetime.isoformat()
         python_type = datetime
 
@@ -365,8 +424,8 @@ class TestDatetimeHandler(object):
             python_type
         ) == original_datetime
 
-    def test_datetime_simple(self):
-        original_datetime = datetime_simple()
+    def test_datetime_simple(self, datetime_simple):
+        original_datetime = datetime_simple
         original_datetime_isoformat = original_datetime.isoformat()
         python_type = datetime
 
@@ -375,8 +434,8 @@ class TestDatetimeHandler(object):
             python_type
         ) == original_datetime
 
-    def test_time_with_micro(self):
-        original_time = time_with_micro()
+    def test_time_with_micro(self, time_with_micro):
+        original_time = time_with_micro
         original_time_isoformat = original_time.isoformat()
         python_type = time
 
@@ -385,8 +444,8 @@ class TestDatetimeHandler(object):
             python_type
         ) == original_time
 
-    def test_time_simple(self):
-        original_time = time_simple()
+    def test_time_simple(self, time_simple):
+        original_time = time_simple
         original_time_isoformat = original_time.isoformat()
         python_type = time
 
@@ -395,8 +454,8 @@ class TestDatetimeHandler(object):
             python_type
         ) == original_time
 
-    def test_date_simple(self):
-        original_date = date_simple()
+    def test_date_simple(self, date_simple):
+        original_date = date_simple
         original_date_isoformat = original_date.isoformat()
         python_type = date
 
@@ -404,3 +463,95 @@ class TestDatetimeHandler(object):
             original_date_isoformat,
             python_type
         ) == original_date
+
+
+@pytest.mark.skipif('cryptography is None')
+class TestAesGcmEngine(object):
+    KEY = b'0123456789ABCDEF'
+
+    def setup_method(self):
+        self.engine = AesGcmEngine()
+        self.engine._initialize_engine(TestAesGcmEngine.KEY)
+
+    def test_roundtrip(self):
+        for number in range(0, 36):
+            plaintext = '0123456789abcdefghijklmnopqrstuvwxyz'[:number]
+            encrypted = self.engine.encrypt(plaintext)
+            decrypted = self.engine.decrypt(encrypted)
+            assert plaintext == decrypted, (
+                "Round-trip failed for len: %d" % number
+            )
+
+    def test_modified_iv_fails_to_decrypt(self):
+        plaintext = 'abcdefgh'
+        encrypted = self.engine.encrypt(plaintext)
+        # 3rd char will be IV. Modify it
+        POS = 3
+        encrypted = encrypted[:POS] + \
+            ('A' if encrypted[POS] != 'A' else 'B') + \
+            encrypted[POS + 1:]
+        with pytest.raises(InvalidCiphertextError):
+            self.engine.decrypt(encrypted)
+
+    def test_modified_tag_fails_to_decrypt(self):
+        plaintext = 'abcdefgh'
+        encrypted = self.engine.encrypt(plaintext)
+        # 19th char will be tag. Modify it
+        POS = 19
+        encrypted = encrypted[:POS] + \
+            ('A' if encrypted[POS] != 'A' else 'B') + \
+            encrypted[POS + 1:]
+        with pytest.raises(InvalidCiphertextError):
+            self.engine.decrypt(encrypted)
+
+    def test_modified_ciphertext_fails_to_decrypt(self):
+        plaintext = 'abcdefgh'
+        encrypted = self.engine.encrypt(plaintext)
+        # 43rd char will be ciphertext. Modify it
+        POS = 43
+        encrypted = encrypted[:POS] + \
+            ('A' if encrypted[POS] != 'A' else 'B') + \
+            encrypted[POS + 1:]
+        with pytest.raises(InvalidCiphertextError):
+            self.engine.decrypt(encrypted)
+
+    def test_too_short_ciphertext_fails_to_decrypt(self):
+        plaintext = 'abcdefgh'
+        encrypted = self.engine.encrypt(plaintext)[:20]
+        with pytest.raises(InvalidCiphertextError):
+            self.engine.decrypt(encrypted)
+
+    def test_different_ciphertexts_each_time(self):
+        plaintext = 'abcdefgh'
+        encrypted1 = self.engine.encrypt(plaintext)
+        encrypted2 = self.engine.encrypt(plaintext)
+        assert self.engine.decrypt(encrypted1) == \
+            self.engine.decrypt(encrypted2)
+        # The following has a very low probability of failing
+        # accidentally (2^-96)
+        assert encrypted1 != encrypted2
+
+
+class TestAesGcmEncryptedType(EncryptedTypeTestCase):
+
+    @pytest.fixture
+    def encryption_engine(self):
+        return AesGcmEngine
+
+    # GCM doesn't need padding. This is here just because we're reusing test
+    # code that requires this
+    @pytest.fixture
+    def padding_mechanism(self):
+        return 'pkcs5'
+
+    def test_lookup_by_encrypted_string(self, session, User, user, user_name):
+        test = session.query(User).filter(
+            User.username == "someonex"
+        ).first()
+
+        # With probability 1-2^-96, the 2 different encryptions will choose a
+        # different IV, and will therefore result in different ciphertexts.
+        # Thus, the 2 values will almost certainly be different, even though
+        # we're really searching for the same username. Hence, the above search
+        # will fail
+        assert test is None
